/****************************************************************************
Date: 2/3/97
File: memmgr.hpp
Description:	FREE STORE MEMORY MANAGER for DOS TSR
	
	A DOS TSR cannot generally call the DOS memory manager. This is
	a simple memory manager for use in a TSR. The algorithm used
	is a linear list. Memory for new objects is allocated sequentially
	in memory. Memory is NOT reclaimed until ALL objects have been deleted.
	Then, we restart at the top of the list.

	Memory blocks will always be word-aligned.

	This memory manager replaces the global operators new and delete.

	The user is responsible for specifying how much memory will
	be in the freestore by setting the compile-time constant
	FREESTORESIZE to the desired size in bytes.

	If memory allocation fails, NULL will be returned. The user can
	check for allocation failures by examining the global variable 
	"Mem_OutOfMemory" which will be set to BOOL_TRUE if ANY allocation
	attempt has failed. This is reset to BOOL_FALSE only when all memory
	is freed.

History
*****************************************************************************/
#ifndef MEMMGR_HPP
#define MEMMGR_HPP

#include <new.h>	// function prototypes
#include "loctypes.h"

extern BOOL Mem_OutOfMemory; // Global Flag

#endif	// memmgr.hpp
