/****************************************************************************
Date: 2/20/97
File: parser.cpp
Description: 	LINE-ORIENTED, TEXT FILE PARSER CLASS

History:
*****************************************************************************/
#include <stddef.h>
#include <string.h>
#include <dos.h>
#include <fcntl.h>

#include "parser.hpp"

// Constructors
PARSER::PARSER() :
	COMMENT(PARSER_COMMENT),
	WHITESPACE(PARSER_WHITESPACE),
	eOpen(BOOL_FALSE) {
}

PARSER::PARSER(CHAR cComment, const CHAR* pszWhiteSpace) :
	COMMENT(cComment),
	WHITESPACE(pszWhiteSpace),
	eOpen(BOOL_FALSE) {
}


BOOL	PARSER::Open(const CHAR* pszFileName) {
	if (eOpen) {
		return BOOL_FALSE;
	}
	unLine = 0;	// reset line number
	eEOF = BOOL_FALSE;

	if (0 == _dos_open(pszFileName, O_RDONLY, &nFileHandle) ) {
		eOpen = BOOL_TRUE;
	}
	return eOpen;
}

VOID	PARSER::Close() {
	if (eOpen) {
		eOpen = BOOL_FALSE;
		_dos_close(nFileHandle);
	}
}

PARSER::~PARSER() { Close(); }

UINT	PARSER::ReadLine(CHAR FAR* aBuffer, UINT unBuffSize, INT nFileHandle) {
	
	CHAR FAR* pBuffer = aBuffer;
	UINT unCharCount = 0;

	do {
		// Read 1 char from file into user's buffer
		UINT unActualCount;
		UINT unErrorCode =_dos_read(nFileHandle, pBuffer, 1, &unActualCount);

		// if an error occured or EOF, break
		if ( unErrorCode || (unActualCount == 0) ) {
			eEOF = BOOL_TRUE;
			break;
		}

		// if the character was a <CR> or 0, break;
		if ( (*pBuffer == PARSER_ENDL) || (*pBuffer == 0) ) {
			break;
		}

		if (unCharCount < unBuffSize) {
			++unCharCount;
			++pBuffer;
		}

	} while(BOOL_TRUE);
	*pBuffer = 0;	// add NUL terminator
	return unCharCount;
}

CHAR*	PARSER::GetToken() {
	CHAR* pszToken;
	do {
		do {
			unLine++;
			if ( !ReadLine(szBuffer, BUFFSIZE, nFileHandle) ) {
				return NULL;
			}
			strcpy(szLine, szBuffer);

			pszToken = strtok(szBuffer, WHITESPACE);

		} while (pszToken == NULL);
	} while ( *pszToken == COMMENT );

	return pszToken;
}

// end parser.cpp
