/**************************************************************************
		Copyright 1996 - A. J. Monteiro
date: 11/22/96
file: picdrv.cpp

title:	PICDRV - Programmable Interrupt Controller Driver class    
  
public:
	Install(UINT unIRQ, INTHANDLER pfnIntHandler)
	EndOfInterrupt()
	CallOldHandler()
	Restore()

description:

history:  AJM initial version
**************************************************************************/
#include "picdrv.hpp"

#pragma check_stack( off )
#pragma check_pointer( off )

IOADDRESS PICDRV::GetPicMaskReg(UINT unIRQNumber) {
	if ( unIRQNumber > PIC1LASTIRQ ) {
 		return PIC2MASKREG;
	}
	else {
		return PIC1MASKREG;
	}
}


UINT PICDRV::GetPicVector(UINT unIRQNumber) {
	if ( unIRQNumber > PIC1LASTIRQ ) {
 		return PIC2VECTOR + unIRQNumber;
	}
	else {
		return PIC1VECTOR + unIRQNumber;
	}
}


UINT	PICDRV::GetPicMask(UINT unIRQNumber) {
 	return (1 << (unIRQNumber % 8));
}

BOOL	PICDRV::Install(UINT unIRQNumber, INTHANDLER pfnIntHandler) {
		
	//***** Check IRQ for Validity ************************
	if (unIRQNumber > PIC2LASTIRQ) {
		return BOOL_FALSE;
	}
	unIRQ = (UCHAR) unIRQNumber;	// Save

	
        //***** Save old interrupt handler **************
	UINT unVector = GetPicVector(unIRQ);
	pfnOldIntHandler = getvect(unVector);

	//***** Set new interrupt handler ***************
	setvect(unVector, pfnIntHandler); 

	//***** Enable interrupt at PIC *****************
	// note that a 1 in the MASK disables the IRQ
	IOADDRESS PicMaskReg = GetPicMaskReg(unIRQ);
	UINT	  unOldPicMask = inp(PicMaskReg);
	UINT	  unSelect = GetPicMask(unIRQ);
	eWasEnabled = (BOOL) !(unOldPicMask & unSelect);
	outp(PicMaskReg, unOldPicMask & ~unSelect);

	return BOOL_TRUE;
}


// restore
VOID	PICDRV::Restore() {

	//***** restore old vector **********************
	UINT unVector = GetPicVector(unIRQ);
	setvect(unVector, pfnOldIntHandler);

	//***** Restore Mask Register *******************
	// If IRQ was in use, leave PIC enabled.
	// Note that a 1 DISABLES the interrupt
	if (!eWasEnabled) {
		IOADDRESS PicMaskReg = GetPicMaskReg(unIRQ);
		outp(PicMaskReg, inp(PicMaskReg) | GetPicMask(unIRQ) );
	}

}

// picdrv.cpp
