/**************************************************************************
date: 8/19/96
file: slink.cpp

title:    SERIALLINK - Serial Communications Link class
  
public:
	SERIALLINK(	CHAR*	pUserRxBuffer,
			UINT	unRxBufferSize,
			CHAR	cEndOfMsg,
			USHORT	unTimeOut)
	VOID	Send(const CHAR* pData, size_t TxCount=0)
	UINT	Receive()
	BOOL	TimeOut()
	VOID	Reset()
	~SERIALLINK()

	// from COMDRV base class
	BOOL	Open( 	UINT	unComPort,
			UINT	unBitRate,
                        UINT    unDataBits,
                        UARTPARITY eParity,
                        UINT    unStopBits,
			UINT	unIRQ 		= DEFAULTIRQ,
			IOADDRESS Address 	= DEFAULTADDRESS)
        VOID    Putc(CHAR cChar)
	INT	Getc() 
        VOID    Write(const CHAR* pUserData, UINT unCount)
	INT	Read(CHAR* pUserBuffer, UINT unMaxCount)
	VOID	ClearBuffers()
	VOID	Close()

description:
	Provides message-oriented serial communications link to a serial 
	port device. Send() starts a response "timeout" timer. This can
	be checked with TimeOut(). The EndOfMsg character is used
	to recognize a complete receive message. It is also appended to
	transmit messages sent with Send().

	This class is publicly derived from the COMDRV class. 

history:  AJM initial version
**************************************************************************/
#include "slink.hpp"

#pragma check_stack( off )
#pragma check_pointer( off )

SERIALLINK::SERIALLINK( CHAR*	pUserRxBuffer,
			UINT	unRxBufferSize,
			CHAR	cEndOfMsgDelimiter,
			USHORT	unTimeOut) :

	COMDRV(),
	Timer(),
	unTimeOut(unTimeOut),
	pRxBuffer(pUserRxBuffer),
	pRxData(pUserRxBuffer),
	unRxBufferSize(unRxBufferSize),
	unRxCount(0),
	cEndOfMsg(cEndOfMsgDelimiter) {
}

VOID	SERIALLINK::Send( const CHAR* pData, size_t TxCount) {
	if (TxCount == 0) {
		TxCount = strlen(pData);
	}
	COMDRV::Write(pData, TxCount);
	COMDRV::Putc(cEndOfMsg);
	Timer.Start(unTimeOut);
}

UINT	SERIALLINK::Receive() {
	INT	nChar;
	UINT	unReturnCount = 0;

	while ( (nChar = Getc()) != COMDRV_EOF ) {

		*pRxData++ = (CHAR) nChar;
		unRxCount++;
		if (nChar == cEndOfMsg) {
			Timer.Stop();
			pRxData = pRxBuffer;	
			unReturnCount = unRxCount;
			unRxCount = 0;
			break;
		}
	}
	return unReturnCount;
}

BOOL	SERIALLINK::TimeOut() {
	return Timer.IsExpired();
}

VOID	SERIALLINK::Reset() {
	ClearBuffers();
	pRxData = pRxBuffer;
	unRxCount = 0;
	return;
}

SERIALLINK::~SERIALLINK() { }
