/**************************************************************************
		Copyright 1996 - A. J. Monteiro
date: 11/22/96
file: uartbase.hpp

title:          UARTBASE - Abstract Base class for UART devices    
  
public:
        // General
        virtual VOID    Open(IOADDRESS Address) = 0
	virtual VOID	Close() = 0

        // Modem Status (optional)
        virtual BOOL    IsRLSD()                // Carrier Detect
        virtual BOOL    IsRI()                  // Ring Indicator
        virtual BOOL    IsDSR()                 // Data Set Ready
        virtual BOOL    IsCTS()                 // Clear To Send

        // Modem Control (optional)
        virtual VOID    SetModemLeads() 	// set leads for normal operation
        virtual VOID    ClearModemLeads() 	// clear all leads

        // Line Status
        virtual BOOL    IsRDR() = 0             // Receiver Data Ready
        virtual BOOL    IsTHRE() = 0            // Transmit Holding Reg Empty
        virtual BOOL    IsTRE() = 0             // Transmit Reg Empty

        // Line Control
        virtual VOID    SetLine(UINT unBitRate,
                                UINT unDataBits,
                                UINT unStopBits,
                                UARTPARITY eParity) = 0

        // Interrupts
        virtual UARTINTID GetInterruptID() = 0
        virtual VOID    EnableInt(UINT unSelect) = 0   // use UARTINTENABLE
        virtual VOID    DisableInt(UINT unSelect) = 0  // use UARTINTENABLE
        virtual VOID    ClearInterrupts() = 0

        // Data
        virtual VOID    PutData(char c) = 0
        virtual INT     GetData() = 0
      
description:
        Provides UART device interface and basic definitions.

history:  AJM initial version
**************************************************************************/
#ifndef UARTBASE_HPP
#define UARTBASE_HPP

#pragma check_stack( off )
#pragma check_pointer( off )

#include "loctypes.h"	// local types

// Parity Select
enum UARTPARITY {
        UARTPARITY_NONE                 = 0x00,
        UARTPARITY_ODD                  = 0x08,
        UARTPARITY_MARK                 = 0x10,
        UARTPARITY_EVEN                 = 0x18,
        UARTPARITY_SPACE                = 0x38
};

// Interrupt Enable Select, use in EnableInt() and DisableInt()
enum UARTINTENABLE {
        UARTINTENABLE_ALL               = 0x0f,
        UARTINTENABLE_MODEMSTATUS       = 0x08,
        UARTINTENABLE_LINESTATUS        = 0x04,
        UARTINTENABLE_RDR               = 0x02,
        UARTINTENABLE_THRE              = 0x01
};

// Interrupt Identification
enum UARTINTID {
        UARTINTID_MODEMSTATUS           = 0x00,
        UARTINTID_NONE                  = 0x01,
        UARTINTID_THRE                  = 0x02,
        UARTINTID_RDR                   = 0x04,
        UARTINTID_LINESTATUS            = 0x06

};


class UARTBASE {
public:
        // General
        virtual VOID    Open(IOADDRESS address) = 0;
	virtual VOID	Close() = 0;

        // Modem Status 
	virtual BOOL	IsRLSD() { return BOOL_TRUE; }	// Carrier Detect
	virtual BOOL	IsRI()	 { return BOOL_FALSE; }	// Ring Indicator
	virtual BOOL	IsDSR()  { return BOOL_TRUE; }	// Data Set Ready
	virtual BOOL	IsCTS()  { return BOOL_TRUE; }	// Clear To Send
                                                        
        // Modem Control
        virtual VOID    SetModemLeads(); 	// set leads for normal operation
        virtual VOID    ClearModemLeads(); 	// clear all leads

        // Line Status
        virtual BOOL    IsRDR() = 0;            // Receiver Data Ready
        virtual BOOL    IsTHRE() = 0;           // Transmit Holding Reg Empty
        virtual BOOL    IsTRE() = 0;            // Transmit Reg Empty

        // Line Control
        virtual VOID    SetLine(UINT unBitRate,
                                UINT unDataBits,
                                UINT unStopBits,
                                UARTPARITY eParity) = 0;

        // Interrupts
        virtual UARTINTID GetInterruptID() = 0;
        virtual VOID    EnableInt(UINT	unSelect) = 0;
        virtual VOID    DisableInt(UINT unSelect) = 0;
        virtual VOID    ClearInterrupts() = 0;

        // Data
        virtual VOID    PutData(char c) = 0;
        virtual INT     GetData() = 0;
};
#endif // uartbase.hpp
