/****************************************************************************
Copyright 1997 Anthony Monteiro

Date: 11/19/97
File: xpdrfxd.hpp
Description:	FIXED FREQUENCY TRANSPONDER CLASS

	Fixed frequency transponders have a fixed uplink frequency
	and modulation mode that do not change.

	This class DOES allow tuning of the output frequency and
	changing the output mode. While this shouldn't be necessary,
	it may be more "operator-friendly."

History
	11/19/97 Version 1.0
*****************************************************************************/
#ifndef XPDRFXD_HPP
#define XPDRFXD_HPP

#include "loctypes.h"
#include "xpdrbase.hpp" 	// Transponder base class

class FIXEDTRANSPONDER: public TRANSPONDER {
public:
	FIXEDTRANSPONDER(const TRANSPONDERPARAMS& Params) {
		TRANSPONDER::dOutputFreq = Params.dOutFreq;
		TRANSPONDER::eOutputMode = Params.eOutMode;
		TRANSPONDER::dInputFreq  = Params.dParam;
		TRANSPONDER::eInputMode  = Params.eInMode;
	}

	VOID	SetInputFreq(DOUBLE dFreq) { }		// do nothing

	VOID	SetOutputFreq(DOUBLE dFreq) { 
		TRANSPONDER::dOutputFreq = dFreq;
	}

	VOID	SetInputMode(MODULATION eMode) {} 	// do nothing

	VOID	SetOutputMode(MODULATION eMode) { 
		TRANSPONDER::eOutputMode = eMode;
	}
};
#endif // xpdrfxd.hpp
